#include <stdio.h>
#include "platform.h"
#include "xil_printf.h"
#include "xparameters.h"
#include "xil_io.h"
#include "xgpio.h"
#include "xintc.h"
#include "xintc_l.h"
#include "xil_exception.h"
#include "microblaze_sleep.h"

#define INTC_DEVICE_ID		  XPAR_INTC_0_DEVICE_ID

#define GPIO_DEVICE_ID		  XPAR_GPIO_0_DEVICE_ID
#define INTC_HANDLER		  XIntc_InterruptHandler

XGpio Gpio;
XIntc Intc; /* The Instance of the Interrupt Controller Driver */

void Init_IO(void);
int Init_Interrupt(void);
void InterruptHandler(void *CallbackRef);


int main()
{
    init_platform();
    Init_IO();
    int stat=0;
    stat = Init_Interrupt();
    unsigned int count = 0, sw = 0;

   while(1)
   {
	   sleep(1);
	   xil_printf("Count: %u\r\n", count);
	   count++;
	   sw = XGpio_DiscreteRead(&Gpio, 1);
	   xil_printf("Buttons: %u\r\n", sw);
	   sw = 0;

   }

    cleanup_platform();
    return 0;
}

void Init_IO(void)
{

	int Status;
	Status = XGpio_Initialize(&Gpio, GPIO_DEVICE_ID);
	usleep(100);
	if (Status != XST_SUCCESS) {
		xil_printf("Init GPIO fail\n\r");
	}
	else
	{
		xil_printf("Success: Pushbuttons Initialized\n\r");
	}
	XGpio_SetDataDirection(&Gpio, 1, 0xf);  // Pushbuttons
	usleep(100);
	XGpio_InterruptClear(&Gpio, 0x0);



}

int Init_Interrupt(void)
{
	int stat;

	microblaze_enable_interrupts();
	stat = XIntc_Initialize(&Intc, INTC_DEVICE_ID);
	usleep(100);
	xil_printf("Initialize Intc: %u\n\r", stat);

	stat = XIntc_Connect(&Intc, XPAR_MICROBLAZE_0_AXI_INTC_AXI_GPIO_0_IP2INTC_IRPT_INTR, (XInterruptHandler)InterruptHandler, (void*) 0);
	usleep(100);
	xil_printf("Connecting Intc with code: %u\n\r", stat);

	usleep(100);
	XIntc_Enable(&Intc, XPAR_MICROBLAZE_0_AXI_INTC_AXI_GPIO_0_IP2INTC_IRPT_INTR); //This works intermittently
	xil_printf("Enabling Intc \n\r");

	usleep(100);
	XIntc_Start(&Intc, XIN_REAL_MODE);
	xil_printf("Starting Intc \n\r");

	XIntc_MasterEnable(&Intc);
	xil_printf("Enable Master \n\r");

	Xil_ExceptionInit();
	Xil_ExceptionRegisterHandler(XIL_EXCEPTION_ID_M_AXI_I_EXCEPTION, (XExceptionHandler)INTC_HANDLER, &Intc);
	xil_printf("Enable Exceptions \n\r");
	Xil_ExceptionEnable();

	//XGpio_InterruptEnable(&Gpio, 0xf);
	usleep(100);
	//XGpio_InterruptGlobalEnable(&Gpio);
	usleep(100);
	return stat;

}

void InterruptHandler(void *CallbackRef)
{
	xil_printf("Received the Interrupt\n\r");
	XGpio_InterruptClear(&Gpio, 0x0);
	XIntc_Acknowledge(&Intc, XPAR_MICROBLAZE_0_AXI_INTC_AXI_GPIO_0_IP2INTC_IRPT_INTR);

}

